@@ -1,3 +1,7 @@
+import django.db.models.options as options
+
+options.DEFAULT_NAMES = options.DEFAULT_NAMES + ("lookup_fields", "lookup_by_model")
+
 SECRET_KEY = 'secret'
 
 INSTALLED_APPS = [
@@ -15,3 +19,5 @@ DATABASES = {
 }
 
 ROOT_URLCONF = 'tests.urls'
+
+DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
